Object.defineProperty(exports, '__esModule', { value: true });

const instrumentation = require('@opentelemetry/instrumentation');
const instrumentationFastify = require('@opentelemetry/instrumentation-fastify');
const core = require('@sentry/core');
const addOriginToSpan = require('../../utils/addOriginToSpan.js');

const _fastifyIntegration = (() => {
  return {
    name: 'Fastify',
    setupOnce() {
      instrumentation.registerInstrumentations({
        instrumentations: [
          new instrumentationFastify.FastifyInstrumentation({
            requestHook(span) {
              addOriginToSpan.addOriginToSpan(span, 'auto.http.otel.fastify');
            },
          }),
        ],
      });
    },
  };
}) ;

/**
 * Express integration
 *
 * Capture tracing data for fastify.
 */
const fastifyIntegration = core.defineIntegration(_fastifyIntegration);

exports.fastifyIntegration = fastifyIntegration;
//# sourceMappingURL=fastify.js.map
