Object.defineProperty(exports, '__esModule', { value: true });

const instrumentation = require('@opentelemetry/instrumentation');
const instrumentationGraphql = require('@opentelemetry/instrumentation-graphql');
const core = require('@sentry/core');
const addOriginToSpan = require('../../utils/addOriginToSpan.js');

const _graphqlIntegration = (() => {
  return {
    name: 'Graphql',
    setupOnce() {
      instrumentation.registerInstrumentations({
        instrumentations: [
          new instrumentationGraphql.GraphQLInstrumentation({
            ignoreTrivialResolveSpans: true,
            responseHook(span) {
              addOriginToSpan.addOriginToSpan(span, 'auto.graphql.otel.graphql');
            },
          }),
        ],
      });
    },
  };
}) ;

/**
 * GraphQL integration
 *
 * Capture tracing data for GraphQL.
 */
const graphqlIntegration = core.defineIntegration(_graphqlIntegration);

exports.graphqlIntegration = graphqlIntegration;
//# sourceMappingURL=graphql.js.map
