Object.defineProperty(exports, '__esModule', { value: true });

const instrumentation = require('@opentelemetry/instrumentation');
const instrumentationMongodb = require('@opentelemetry/instrumentation-mongodb');
const core = require('@sentry/core');
const addOriginToSpan = require('../../utils/addOriginToSpan.js');

const _mongoIntegration = (() => {
  return {
    name: 'Mongo',
    setupOnce() {
      instrumentation.registerInstrumentations({
        instrumentations: [
          new instrumentationMongodb.MongoDBInstrumentation({
            responseHook(span) {
              addOriginToSpan.addOriginToSpan(span, 'auto.db.otel.mongo');
            },
          }),
        ],
      });
    },
  };
}) ;

/**
 * MongoDB integration
 *
 * Capture tracing data for MongoDB.
 */
const mongoIntegration = core.defineIntegration(_mongoIntegration);

exports.mongoIntegration = mongoIntegration;
//# sourceMappingURL=mongo.js.map
