Object.defineProperty(exports, '__esModule', { value: true });

const instrumentation = require('@opentelemetry/instrumentation');
const instrumentationMongoose = require('@opentelemetry/instrumentation-mongoose');
const core = require('@sentry/core');
const addOriginToSpan = require('../../utils/addOriginToSpan.js');

const _mongooseIntegration = (() => {
  return {
    name: 'Mongoose',
    setupOnce() {
      instrumentation.registerInstrumentations({
        instrumentations: [
          new instrumentationMongoose.MongooseInstrumentation({
            responseHook(span) {
              addOriginToSpan.addOriginToSpan(span, 'auto.db.otel.mongoose');
            },
          }),
        ],
      });
    },
  };
}) ;

/**
 * Mongoose integration
 *
 * Capture tracing data for Mongoose.
 */
const mongooseIntegration = core.defineIntegration(_mongooseIntegration);

exports.mongooseIntegration = mongooseIntegration;
//# sourceMappingURL=mongoose.js.map
