Object.defineProperty(exports, '__esModule', { value: true });

const instrumentation = require('@opentelemetry/instrumentation');
const instrumentationMysql2 = require('@opentelemetry/instrumentation-mysql2');
const core = require('@sentry/core');
const addOriginToSpan = require('../../utils/addOriginToSpan.js');

const _mysql2Integration = (() => {
  return {
    name: 'Mysql2',
    setupOnce() {
      instrumentation.registerInstrumentations({
        instrumentations: [
          new instrumentationMysql2.MySQL2Instrumentation({
            responseHook(span) {
              addOriginToSpan.addOriginToSpan(span, 'auto.db.otel.mysql2');
            },
          }),
        ],
      });
    },
  };
}) ;

/**
 * MySQL2 integration
 *
 * Capture tracing data for mysql2
 */
const mysql2Integration = core.defineIntegration(_mysql2Integration);

exports.mysql2Integration = mysql2Integration;
//# sourceMappingURL=mysql2.js.map
