Object.defineProperty(exports, '__esModule', { value: true });

const instrumentation = require('@opentelemetry/instrumentation');
const instrumentationPg = require('@opentelemetry/instrumentation-pg');
const core = require('@sentry/core');
const addOriginToSpan = require('../../utils/addOriginToSpan.js');

const _postgresIntegration = (() => {
  return {
    name: 'Postgres',
    setupOnce() {
      instrumentation.registerInstrumentations({
        instrumentations: [
          new instrumentationPg.PgInstrumentation({
            requireParentSpan: true,
            requestHook(span) {
              addOriginToSpan.addOriginToSpan(span, 'auto.db.otel.postgres');
            },
          }),
        ],
      });
    },
  };
}) ;

/**
 * Postgres integration
 *
 * Capture tracing data for pg.
 */
const postgresIntegration = core.defineIntegration(_postgresIntegration);

exports.postgresIntegration = postgresIntegration;
//# sourceMappingURL=postgres.js.map
