Object.defineProperty(exports, '__esModule', { value: true });

const core = require('@sentry/core');
const api = require('./api.js');

/**
 * This is for legacy reasons, and returns a proxy object instead of a hub to be used.
 * @deprecated Use the methods directly.
 */
function getCurrentHub() {
  return {
    isOlderThan(_version) {
      return false;
    },

    bindClient(client) {
      const scope = core.getCurrentScope();
      scope.setClient(client);
    },

    pushScope() {
      // TODO: This does not work and is actually deprecated
      return core.getCurrentScope();
    },

    popScope() {
      // TODO: This does not work and is actually deprecated
      return false;
    },

    withScope: core.withScope,
    getClient: () => api.getClient() ,
    getScope: core.getCurrentScope,
    getIsolationScope: core.getIsolationScope,
    captureException: (exception, hint) => {
      return core.getCurrentScope().captureException(exception, hint);
    },
    captureMessage: (message, level, hint) => {
      return core.getCurrentScope().captureMessage(message, level, hint);
    },
    captureEvent: core.captureEvent,
    addBreadcrumb: core.addBreadcrumb,
    setUser: core.setUser,
    setTags: core.setTags,
    setTag: core.setTag,
    setExtra: core.setExtra,
    setExtras: core.setExtras,
    setContext: core.setContext,

    getIntegration(integration) {
      // eslint-disable-next-line deprecation/deprecation
      return api.getClient().getIntegration(integration);
    },

    startTransaction(
      _context,
      _customSamplingContext,
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
    ) {
      // eslint-disable-next-line no-console
      console.warn('startTransaction is a noop in @sentry/node-experimental. Use `startSpan` instead.');
      // We return an object here as hub.ts checks for the result of this
      // and renders a different warning if this is empty
      return {};
    },

    startSession: core.startSession,

    endSession: core.endSession,

    captureSession(endSession) {
      // both send the update and pull the session from the scope
      if (endSession) {
        // eslint-disable-next-line deprecation/deprecation
        return this.endSession();
      }

      // only send the update
      _sendSessionUpdate();
    },

    shouldSendDefaultPii() {
      const client = api.getClient();
      const options = client.getOptions();
      return Boolean(options.sendDefaultPii);
    },
  };
}

/**
 * Sends the current Session on the scope
 */
function _sendSessionUpdate() {
  const scope = core.getCurrentScope();
  const client = api.getClient();

  const session = scope.getSession();
  if (session) {
    client.captureSession(session);
  }
}

exports.getCurrentHub = getCurrentHub;
//# sourceMappingURL=hub.js.map
