import { registerInstrumentations } from '@opentelemetry/instrumentation';
import { GraphQLInstrumentation } from '@opentelemetry/instrumentation-graphql';
import { defineIntegration } from '@sentry/core';
import { addOriginToSpan } from '../../utils/addOriginToSpan.js';

const _graphqlIntegration = (() => {
  return {
    name: 'Graphql',
    setupOnce() {
      registerInstrumentations({
        instrumentations: [
          new GraphQLInstrumentation({
            ignoreTrivialResolveSpans: true,
            responseHook(span) {
              addOriginToSpan(span, 'auto.graphql.otel.graphql');
            },
          }),
        ],
      });
    },
  };
}) ;

/**
 * GraphQL integration
 *
 * Capture tracing data for GraphQL.
 */
const graphqlIntegration = defineIntegration(_graphqlIntegration);

export { graphqlIntegration };
//# sourceMappingURL=graphql.js.map
