import { registerInstrumentations } from '@opentelemetry/instrumentation';
import { MongoDBInstrumentation } from '@opentelemetry/instrumentation-mongodb';
import { defineIntegration } from '@sentry/core';
import { addOriginToSpan } from '../../utils/addOriginToSpan.js';

const _mongoIntegration = (() => {
  return {
    name: 'Mongo',
    setupOnce() {
      registerInstrumentations({
        instrumentations: [
          new MongoDBInstrumentation({
            responseHook(span) {
              addOriginToSpan(span, 'auto.db.otel.mongo');
            },
          }),
        ],
      });
    },
  };
}) ;

/**
 * MongoDB integration
 *
 * Capture tracing data for MongoDB.
 */
const mongoIntegration = defineIntegration(_mongoIntegration);

export { mongoIntegration };
//# sourceMappingURL=mongo.js.map
