import { registerInstrumentations } from '@opentelemetry/instrumentation';
import { MongooseInstrumentation } from '@opentelemetry/instrumentation-mongoose';
import { defineIntegration } from '@sentry/core';
import { addOriginToSpan } from '../../utils/addOriginToSpan.js';

const _mongooseIntegration = (() => {
  return {
    name: 'Mongoose',
    setupOnce() {
      registerInstrumentations({
        instrumentations: [
          new MongooseInstrumentation({
            responseHook(span) {
              addOriginToSpan(span, 'auto.db.otel.mongoose');
            },
          }),
        ],
      });
    },
  };
}) ;

/**
 * Mongoose integration
 *
 * Capture tracing data for Mongoose.
 */
const mongooseIntegration = defineIntegration(_mongooseIntegration);

export { mongooseIntegration };
//# sourceMappingURL=mongoose.js.map
