import { registerInstrumentations } from '@opentelemetry/instrumentation';
import { PgInstrumentation } from '@opentelemetry/instrumentation-pg';
import { defineIntegration } from '@sentry/core';
import { addOriginToSpan } from '../../utils/addOriginToSpan.js';

const _postgresIntegration = (() => {
  return {
    name: 'Postgres',
    setupOnce() {
      registerInstrumentations({
        instrumentations: [
          new PgInstrumentation({
            requireParentSpan: true,
            requestHook(span) {
              addOriginToSpan(span, 'auto.db.otel.postgres');
            },
          }),
        ],
      });
    },
  };
}) ;

/**
 * Postgres integration
 *
 * Capture tracing data for pg.
 */
const postgresIntegration = defineIntegration(_postgresIntegration);

export { postgresIntegration };
//# sourceMappingURL=postgres.js.map
