import { getCurrentScope, withScope, getIsolationScope, captureEvent, addBreadcrumb, setUser, setTags, setTag, setExtra, setExtras, setContext, startSession, endSession } from '@sentry/core';
import { getClient } from './api.js';

/**
 * This is for legacy reasons, and returns a proxy object instead of a hub to be used.
 * @deprecated Use the methods directly.
 */
function getCurrentHub() {
  return {
    isOlderThan(_version) {
      return false;
    },

    bindClient(client) {
      const scope = getCurrentScope();
      scope.setClient(client);
    },

    pushScope() {
      // TODO: This does not work and is actually deprecated
      return getCurrentScope();
    },

    popScope() {
      // TODO: This does not work and is actually deprecated
      return false;
    },

    withScope,
    getClient: () => getClient() ,
    getScope: getCurrentScope,
    getIsolationScope,
    captureException: (exception, hint) => {
      return getCurrentScope().captureException(exception, hint);
    },
    captureMessage: (message, level, hint) => {
      return getCurrentScope().captureMessage(message, level, hint);
    },
    captureEvent,
    addBreadcrumb,
    setUser,
    setTags,
    setTag,
    setExtra,
    setExtras,
    setContext,

    getIntegration(integration) {
      // eslint-disable-next-line deprecation/deprecation
      return getClient().getIntegration(integration);
    },

    startTransaction(
      _context,
      _customSamplingContext,
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
    ) {
      // eslint-disable-next-line no-console
      console.warn('startTransaction is a noop in @sentry/node-experimental. Use `startSpan` instead.');
      // We return an object here as hub.ts checks for the result of this
      // and renders a different warning if this is empty
      return {};
    },

    startSession,

    endSession,

    captureSession(endSession) {
      // both send the update and pull the session from the scope
      if (endSession) {
        // eslint-disable-next-line deprecation/deprecation
        return this.endSession();
      }

      // only send the update
      _sendSessionUpdate();
    },

    shouldSendDefaultPii() {
      const client = getClient();
      const options = client.getOptions();
      return Boolean(options.sendDefaultPii);
    },
  };
}

/**
 * Sends the current Session on the scope
 */
function _sendSessionUpdate() {
  const scope = getCurrentScope();
  const client = getClient();

  const session = scope.getSession();
  if (session) {
    client.captureSession(session);
  }
}

export { getCurrentHub };
//# sourceMappingURL=hub.js.map
